.. _glm_report_examples_ref:

.. only:: html

Examples of GLM reports
=======================

First level report
------------------

ADHD
^^^^

Adapted from :ref:`sphx_glr_auto_examples_04_glm_first_level_plot_adhd_dmn.py`

.. raw:: html
   :file: flm_adhd_dmn.html

BIDS features
^^^^^^^^^^^^^

Adapted from :ref:`sphx_glr_auto_examples_04_glm_first_level_plot_bids_features.py`

.. raw:: html
   :file: flm_bids_features.html

.. _two_runs_glm:

FIAC
^^^^

Adapted from :ref:`sphx_glr_auto_examples_04_glm_first_level_plot_two_runs_model.py`

.. raw:: html
   :file: flm_fiac.html

Surface GLM: empty
^^^^^^^^^^^^^^^^^^

.. raw:: html
   :file: flm_surf_empty.html

Surface GLM
^^^^^^^^^^^

Adapted from :ref:`sphx_glr_auto_examples_04_glm_first_level_plot_localizer_surface_analysis.py`

.. raw:: html
   :file: flm_surf.html

Second level report
-------------------

Volume GLM
^^^^^^^^^^

Adapted from :ref:`sphx_glr_auto_examples_05_glm_second_level_plot_oasis.py`

.. raw:: html
   :file: slm_oasis.html

Surface GLM
^^^^^^^^^^^

.. raw:: html
   :file: slm_surf_empty.html
